@@ -1,3 +1,11 @@
+"""
+Functions to deal with system paths
+"""
+
+__all__ = [
+    'slugify'
+]
+
 def slugify(text, keep_characters=None):
     """Turn any text into a string that can be used in a filename
 
